[llvm-commits] CVS: llvm/lib/CodeGen/MachineDebugInfo.cpp

Jim Laskey jlaskey at apple.com
Mon Feb 13 04:51:02 PST 2006



Changes in directory llvm/lib/CodeGen:

MachineDebugInfo.cpp updated: 1.13 -> 1.14
---
Log message:

Rename to better reflect usage (current and planned.)


---
Diffs of the changes:  (+3 -2)

 MachineDebugInfo.cpp |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)


Index: llvm/lib/CodeGen/MachineDebugInfo.cpp
diff -u llvm/lib/CodeGen/MachineDebugInfo.cpp:1.13 llvm/lib/CodeGen/MachineDebugInfo.cpp:1.14
--- llvm/lib/CodeGen/MachineDebugInfo.cpp:1.13	Fri Feb 10 19:01:30 2006
+++ llvm/lib/CodeGen/MachineDebugInfo.cpp	Mon Feb 13 06:50:38 2006
@@ -887,9 +887,10 @@
   return false;
 }
 
 /// Deserialize - Convert a Value to a debug information descriptor.
 ///
-DebugInfoDesc *MachineDebugInfo::Deserialize(Value *V) {
+// FIXME - use new Value type when available.
+DebugInfoDesc *MachineDebugInfo::getDescFor(Value *V) {
   return DR.Deserialize(V);
 }
 
@@ -887,9 +887,10 @@
 }
 
-/// Deserialize - Convert a Value to a debug information descriptor.
+/// getDescFor - Convert a Value to a debug information descriptor.
 ///






More information about the llvm-commits mailing list